@@ -4,13 +4,12 @@ the contents of Wikimedia SQL dump files.
 """
 
 import gzip
-import sys
 from contextlib import contextmanager
 from pathlib import Path
 from typing import Iterator, Optional, TextIO, Union
-from urllib.error import HTTPError
 
-import wget  # type: ignore
+import requests  # type: ignore
+from tqdm import tqdm  # type: ignore
 
 # Custom type
 PathObject = Union[str, Path]
@@ -66,37 +65,38 @@ def head(file_path: PathObject, n_lines: int = 10, encoding: str = "utf-8") -> N
     return
 
 
-def _progress_bar(
-    current: Union[int, float], total: Union[int, float], width: int = 60
-) -> None:
+def download_file(url: str, file_name: str) -> Optional[Path]:
     """
-    Custom progress bar for wget downloads.
-
-    :param current: bytes downloaded so far
-    :type current: Union[int, float]
-    :param total: Total size of download in bytes or megabytes
-    :type total: Union[int, float]
-    :param width: Progress bar width in chars, defaults to 60
-    :type width: int, optional
+    Download a file from a URL and show a progress indicator. Return the path to the downloaded file.
+    :param url: URL to download from
+    :param file_name: name of the file to download
+    :return: path to the downloaded file
     """
 
-    unit = "bytes"
+    session = requests.Session()
+    response = session.get(url, stream=True)
+    response.raise_for_status()
+    total_size = int(response.headers.get("content-length", 0))
+    block_size = 4096
+    progress_bar = tqdm(total=total_size, unit="iB", unit_scale=True)
 
-    # Show file size in MB for large files
-    if total >= 100000:
-        MB = 1024 * 1024
-        current = current / MB
-        total = total / MB
-        unit = "MB"
+    with open(file_name, "wb") as outfile:
+        for data in response.iter_content(block_size):
+            progress_bar.update(len(data))
+            outfile.write(data)
+    progress_bar.close()
 
-    progress = current / total
-    progress_message = f"Progress: \
-    {progress:.0%} [{current:.1f} / {total:.1f}] {unit}"
-    sys.stdout.write("\r" + progress_message)
-    sys.stdout.flush()
+    if total_size != 0 and progress_bar.n != total_size:
+        raise RuntimeError(
+            f"Downloaded {progress_bar.n} bytes, expected {total_size} bytes"
+        )
+
+    return Path(file_name)
 
 
-def load(database: str, filename: str, date: str = "latest") -> Optional[PathObject]:
+def load(
+    database: str, filename: str, date: str = "latest", extension: str = "sql"
+) -> Optional[PathObject]:
     """
     Load a dump file from a Wikimedia public directory if the
     user is in a supported environment (PAWS, Toolforge...). Otherwise, download dump file from the web and save in the current working directory. In both cases,the function returns a path-like object which can be used to access the file. Does not check if the file already exists on the path.
@@ -111,6 +111,8 @@ def load(database: str, filename: str, date: str = "latest") -> Optional[PathObj
     :param date: Date the dump was generated, defaults to "latest". If "latest"
         is not used, the date format should be "YYYYMMDD"
     :type date: str, optional
+    :param extension: The file extension. Defaults to 'sql'
+    :type extension: str
     :return: Path to dump file
     :rtype: Optional[PathObject]
     """
@@ -118,19 +120,12 @@ def load(database: str, filename: str, date: str = "latest") -> Optional[PathObj
     paws_root_dir = Path("/public/dumps/public/")
     dumps_url = "https://dumps.wikimedia.org/"
     subdir = Path(database, date)
-    extended_filename = f"{database}-{date}-{filename}.sql.gz"
+    extended_filename = f"{database}-{date}-{filename}.{extension}.gz"
     file_path = Path(extended_filename)
 
     if paws_root_dir.exists():
-        dump_file = Path(paws_root_dir, subdir, file_path)
+        return Path(paws_root_dir, subdir, file_path)
 
     else:
-        url = f"{dumps_url}{str(subdir)}/{str(file_path)}"
-        try:
-            print(f"Downloading {url}")
-            dump_file = wget.download(url, bar=_progress_bar)
-        except HTTPError as e:
-            print(f"HTTPError: {e}")
-            raise
-
-    return Path(dump_file)
+        url = f"{dumps_url}{str(subdir)}/{str(extended_filename)}"
+        return download_file(url, extended_filename)
