@@ -1,13 +1,16 @@
 import os
 from pathlib import Path, PosixPath
-from urllib.error import HTTPError
 
 import pytest
+import requests
 
 from mwsql.utils import _open_file, head, load
 
 from .helpers import Capturing
 
+# from urllib.error import HTTPError
+
+
 CURRENT_DIR = Path(__file__).parent
 DATA_DIR = CURRENT_DIR.parent / "data"
 FILEPATH_GZ = DATA_DIR / "testfile.sql.gz"
@@ -15,32 +18,34 @@ FILEPATH_UNZIPPED = DATA_DIR / "testfile.sql"
 
 
 @pytest.mark.parametrize(
-    "database,filename,date,expected",
+    "database,filename,date,extension,expected",
     [
         (
             "simplewiki",
             "change_tag_def",
             "latest",
+            "sql",
             "simplewiki-latest-change_tag_def.sql.gz",
         ),
         (
             "simplewiki",
             "change_tag",
             "latest",
+            "sql",
             "simplewiki-latest-change_tag.sql.gz",
         ),
-        ("bewiki", "site_stats", "latest", "bewiki-latest-site_stats.sql.gz"),
-        ("nlwiktionary", "sites", "latest", "nlwiktionary-latest-sites.sql.gz"),
+        ("bewiki", "site_stats", "latest", "sql", "bewiki-latest-site_stats.sql.gz"),
+        ("nlwiktionary", "sites", "latest", "sql", "nlwiktionary-latest-sites.sql.gz"),
     ],
 )
-def test_load(database, filename, date, expected):
-    f = load(database, filename, date)
+def test_load(database, filename, date, extension, expected):
+    f = load(database, filename, date, extension)
     assert f == PosixPath(expected)
     os.remove(f)
 
 
 def test_load_HTTPError():
-    with pytest.raises(HTTPError):
+    with pytest.raises(requests.exceptions.HTTPError):
         load("simplewiki", "non-existing-filename", "latest")
 
 
